.. _release-0-6-0:

0.6.0
=====

Bokeh ``0.6.0`` (Sep 2014) is an incremental update:

* Abstract Rendering recipes for large data sets: isocontour, heatmap, hdalpha
* Improved, configurable tool bar for plots
* Full Python 3 support for bokeh-server
* Much expanded User Guide
* Support for multiple axes
* Plot object graph query interface
* New charts in bokeh.charts: TimeSeries and Categorical HeatMap
* Hit-testing for patch glyphs
